@@ -1,18 +1,13 @@
 import logging
 import os
-
-from jax.config import config
-
-config.update("jax_enable_x64", True)
-if os.environ.get("DEBUGNANS") == "TRUE":
-    config.update("jax_debug_nans", True)
-if os.environ.get("NOJIT") == "TRUE":
-    config.update('jax_disable_jit', True)
-
+import jax
 logging.basicConfig(format="")
 logger = logging.getLogger("deltapv")
 logger.setLevel("INFO")
 
+jax.config.update("jax_enable_x64", True)
+
+
 from deltapv import (simulator, materials, plotting,
                      objects, spline, physics, util)
 from deltapv.materials import create_material, load_material
